#
# spec file for package loupe
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           loupe
Version:        47.2
Release:        bp160.1.1
Summary:        A simple image viewer application
License:        GPL-3.0-or-later
URL:            https://gitlab.gnome.org/GNOME/loupe
Source0:        %{name}-%{version}.tar.zst
Source1:        vendor.tar.zst

BuildRequires:  appstream-glib
BuildRequires:  cargo-packaging >= 1.2.0+3
BuildRequires:  desktop-file-utils
BuildRequires:  itstool
BuildRequires:  meson
BuildRequires:  pkgconfig
BuildRequires:  pkgconfig(gtk4) >= 4.13.6
BuildRequires:  pkgconfig(gweather4) >= 4.0.0
BuildRequires:  pkgconfig(lcms2)
BuildRequires:  pkgconfig(libadwaita-1) >= 1.4.0
BuildRequires:  pkgconfig(libheif) >= 1.14.2
BuildRequires:  pkgconfig(libseccomp) >= 2.5.0
Requires:       glycin-loaders

%description
%{summary} written with GTK4 and Rust.

%lang_package

%prep
%autosetup -p1 -a1

%build
export RUSTFLAGS="%{build_rustflags}"
%meson \
	%{nil}
%meson_build

%install
export RUSTFLAGS="%{build_rustflags}"
%meson_install
%find_lang %{name} %{?no_lang_C}

%check
export RUSTFLAGS="%{build_rustflags}"
%cargo_test
# No meson_test exists upstream yet, so run these manually
appstream-util validate-relax --nonet %{buildroot}%{_datadir}/metainfo/org.gnome.Loupe.metainfo.xml
desktop-file-validate %{buildroot}%{_datadir}/applications/org.gnome.Loupe.desktop

%files
%license COPYING.md
%doc README.md
%{_bindir}/%{name}
%{_datadir}/applications/org.gnome.Loupe.desktop
%{_datadir}/dbus-1/services/org.gnome.Loupe.service
%{_datadir}/glib-2.0/schemas/org.gnome.Loupe.gschema.xml
%{_datadir}/help/C/%{name}/
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Loupe.Devel.svg
%{_datadir}/icons/hicolor/scalable/apps/org.gnome.Loupe.svg
%{_datadir}/icons/hicolor/symbolic/apps/org.gnome.Loupe-symbolic.svg
%{_datadir}/metainfo/org.gnome.Loupe.metainfo.xml

%files lang -f %{name}.lang

%changelog
* Sat Nov 23 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.2:
  + Don't call style manager in application constructor since this
    is too early. Do it in startup instead. Without this fix, GTK
    4.17.0 will terminate the app on startup.
* Thu Oct 17 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.1:
  + Add `<branding><color>`s instead of just using
    `GnomeSoftware::key-colors`. That they weren't set was an
    oversight.
  + Fixed:
  - Make the string "Error Details" translatable.
  - Require glycin 2.0.1 crate to detect SVGZ files properly.
* Fri Sep 13 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 47.0:
  + Flickering while images are reloaded. Instead, keep the old
    textures around until a new texture is available.
  + Forcing the zoom to the center of the image is now working
    again. This is especially noticable when using the touchpads
    pinch gesture.
  + When disabling animations in the OS and using the buttons to
    change the image, the wrong image was shown, disabling features
    like zoom.
* Fri Aug 30 2024 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 47.beta.1:
  + Don't force Flatpak sandbox SVGs. This fixes SVGs not loading
    outside of Flatpak.
  + Make the window wider when it would open with a bottom-sheet
    overlay for properties. That way, the properties can be shown
    in a sidebar.
  + Properly detect non-transparent images and down download a
    thumbnail for background detection for them. For some reason,
    the thumbnail download is using a lot of VRAM.
* Wed Apr 10 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.2:
  + Fix fractional scaling beeing blury by setting
    GDK_DEBUG=gl-no-fractional as default.
  + Fix exposure times above 0.5 seconds not being displayed
    correctly in properties.
  + Fix page orientation from print preview dialog is not honored
    for actual print.
* Thu Apr  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.1:
  + Fix fill-space option not being applied when changing the
    orientation in print preview.
  + Fix PNGs not being available when browsing images on SMB
    shares.
  + Don't animate switching between images with the mouse fwd/back
    buttons.
* Fri Mar 15 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.0:
  + Change to stable dependencies
* Mon Mar  4 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.rc:
  + Fix background color detection ignoring small lines in large
    images.
  + Change to "gl" as GSK default renderer instead of "ngl" due to
    performance reasons.
  + Change to sticking to the first error delivered during image
    loading.
* Sun Feb 25 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta.2:
  + Change metainfo to include GNOME group.
  + Change metainfo to use reversed name for the developer id.
  + Change to use latest glycin beta for better metadata
    performance.
* Mon Feb 19 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta.1:
  + Change .desktop file to not include "Slideshow" as keyword.
  + Change help by regenerating pages.
  + Change help to correctly represent zoom.
  + Change to use zbus 4.0.
* Mon Feb 12 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.beta:
  + Fix not reliably returning to restored image when undoing trash
    operation.
  + Added Shift+Delete as shortcut for permanent image deletion.
  + Added build option that makes X11 an optional dependency.
  + Added button to copy coordinates for location in properties.
  + Change to not using animation when changing images via keyboard
    shortcuts.
  + Change to opening image in new window, occupy 40%% of the screen
    instead of 30%%.
  + Change to using "stacked cards" animation when changing images
    via buttons.
  + Changed to show city if it's less than 15km away instead of
    100km before.
- Add pkgconfig(libseccomp) BuildRequires: new dependency.
* Tue Jan 16 2024 Dominique Leuenberger <dimstar@opensuse.org>
- Update to version 46.alpha:
  + Fix "Ctrl + C" copies image instead of metadata if text is
    selected.
  + Fix "g_object_weak_unref" warnings.
  + Fix changing image resets timeout for hiding controls if still
    visible.
  + Fix long file names can newly opened window larger than
    required for image.
  + Fix not always zooming into center when using overlay buttons
    on touchscreen.
  + Fix opening image in different folder ends fullscreen mode.
  + Fix scrollbars disappearing under certain conditions.
  + Add zooming via touchpad scrolling while Ctrl button is
    pressed.
  + Follow G_MESSAGES_DEBUG variable for logging.
  + In print preview, base 100%% image scale on physical dimensions
    of SVGs if specified.
  + In print preview, fix wrong upper input limit in height.
  + In print preview, scale SVGs correctly.
  + More reliably zoom into image position below cursor.
  + Pre-select current image's folder in file-chooser dialog.
  + Remember image properties visibility state.
  + Use GdkSurface:scale instead of scale factor, in theory
    supporting fractional scaling.
  + Use glycin 1.0.
* Thu Nov 30 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.2:
  + Fix order of images gets confused after deleting image
  + Fix image is not shown when sucessfully reloaded after error
  + Fix keyboard shortcuts shows the swipe gestures the wrong way
    round
- Following changes in obs-service-cargo, drop cargo_config as
  source from spec and source, and remove cargo_audit from
  _service, as these are now automated as part of cargo_vendor.
* Tue Nov 14 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.1:
  + Fix sandbox for image decoding not enabled by default
  + Fix printing on different printer than selected
  + Fix print dialog crashes on confirmation
  + Fix print dialog needs second confirmation inside Flatpaks
  + Fix SVGs sometimes not re-rendering for zoom level
  + Fix animated image formats with variable frame length using
    only one length
  + Fix rotation getting applied twice to HEIF images
- Drop patches fixed upstream:
  + loupe_glycin-loaders_sandbox.patch
  + loupe_print_fix.patch
* Tue Nov  7 2023 Dominique Leuenberger <dimstar@opensuse.org>
- Fix build with RPM 4.19: unnumbered patches are no longer
  supported.
* Fri Sep 29 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add loupe_glycin-loaders_sandbox.patch: Enable the glycin-loaders
  sandbox.
  https://gitlab.gnome.org/GNOME/loupe/-/merge_requests/299
- Add loupe_print_fix.patch: print: Use same print operation
  throughout.
  https://gitlab.gnome.org/GNOME/loupe/-/merge_requests/302
* Sun Sep 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.0:
  + Always ask which program to use for "Open With…"
  + SVG: Force minimum tile size of 1000x1000
  + SVG: Don't render first tiles with zoom=1
  + Empty state: Use flat headerbar
  + Fix non-native files with path cannot be deleted
  + Update screenshots
  + Drag and Drop: Only expect sources of type FileList
  + Update SlidingView after removing unsupported image
* Fri Sep 15 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta.1:
  + Reload images when the file is replaced by moving another file
    at it's place
  + Update dependencies
- Change compression in service and tarball produced to zst.
- Update URL to new home on GNOME proper.
* Wed Aug 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add glycin-loaders Requires: Ensure that we have the loaders in
  place.
* Thu Aug 17 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.beta:
  + Newly designed print dialog
  + Added sandboxing for SVG rendering by using glycin
  + Use RaisedBorder for HeaderBar to avoid shadow over images
  + Fix browsing images on SMB shares not working
  + Fix touchscreen gestures not working when zoomed in
  + Fix touchscreen swipe only working on second attempt
  + Added JpegXL support via new glycin version
  + Added overshoot for swipe gesture
  + New custom style for drop targets
  + Changed name to Image Viewer
* Mon Jul 24 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Add back cargo_audit in _service, now that it is back in working
  order.
* Sun Jul 16 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 45.alpha:
  + Add help
  + Disable trashing for non-native files
  + Give toast for latest deleted file priority over the others
  + Only list supported image formats in file chooser
  + Do not guess a potentially different background color for
    opaque images
  + Fix incorrect updates when deleting or changing images
  + Fix SVG zooming with high-res scroll-wheels
  + Use glycin for sandboxed extendable image loading expect for
    SVG
  + Remove backspace as a trash shortcut
  + Change command line to open all given images in one window
  + Do not show "Set as Background" if operation was aborted
  + Let the user select multiple files to open in file chooser
  + Support forward and back mouse buttons
  + Correctly align right-click menu
- Drop loupe-revert-gtk4-unstable-bump.patch: No longer needed.
- Add itstool BuildRequires: New dependency.
* Wed Jun 28 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Use %%build_rustflags instead of the deprecated
  %%__rustflags macro. Requires at least cargo-packaging 1.2.0+3.
* Sun Apr 23 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.2:
  + Use GFile instead of direct file access
  + Do not crash when monitor info is not available
  + Get rid of many unwraps and report issues to UI instead, just
    to be safe
  + Fix displayed times are wrong because they do not respect
    timezones
  + Add basic support for ICC color profiles
  + Support opening multiple files via drag and drop
  + Fix textures and background color not updating when image data
    changed
  + Fix not defaulting to light background color in light theme
  + Fix thumbnail is broken for auto-rotated (EXIF) images
  + Fix high-res scroll wheel issues
  + Fix 100%%/200%% shortcuts ending up at best-fit when window size
    close to 100%%/200%%
  + Add printing support
  + Center new tilings in the viewport, making the first rendered
    tile cover the viewport already
  + Allow dragging (panning) the image with middle button
  + Generate list of mime types in meson and fix list of formats
  + Set actions enabled state based on UI property status, not
    manually everywhere
  + Add and update license headers with script based on commit info
  + Hide overlay controls after inactivity
  + Remove OSD from HeaderBar in fullscreen
  + Drop AdwFlap for HeaderBar
  + Make properties button insensitive if no image shown/loading
  + Move 'toggle fullscreen' button from inner to outer position
  + Add 'all files' filter option to file chooser
- Add pkgconfig(lcms2) BuildRequires: New dependency.
* Wed Apr 12 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Use rustflags export also in check section.
* Tue Apr 11 2023 Luciano Santos <luc14n0@opensuse.org>
- Drop %%rustflags macro definition out of the spec file and use
  %%__rustflags from cargo-packaging package instead. There's no
  need to define it on every spec anymore.
* Thu Apr  6 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Update to version 44.1:
  + Bump GTK dependency to 4.11.1 because of required fixes for
    scaled texture
  + Drop gtk-macros (crate) dependency since it is not needed and
    lacking a LICENSE files
  + Fix WebP support for still images
  + Fix not detecting HEIC files
- Add loupe-revert-gtk4-unstable-bump.patch: Revert bump to
  unstable gtk4 dependency.
* Wed Apr  5 2023 Bjørn Lie <bjorn.lie@gmail.com>
- Initial packaging for openSUSE.
